@@ -27,4 +27,4 @@ class EnumWithSchemaProvider(BaseProvider):
         """
         members: List[TEnum] = list(m for m in cast(Iterable[TEnum], enum_cls)
                                     if not m.name.startswith('_'))
-        return cast(TEnum, self.random_element(members))  # type: ignore
+        return cast(TEnum, self.random_element(members))
